@@ -36,6 +36,7 @@ class Tethys(object):
     remotes_list : list of dict
         list of dict of the S3 remotes to access. The dicts must contain:
         bucket and connection_config.
+
         bucket : str
             A string of the bucket name.
         connection_config : dict or str
@@ -58,15 +59,15 @@ class Tethys(object):
         setattr(self, '_key_patterns', key_patterns)
 
         if isinstance(remotes_list, list):
-            datasets = self.get_remotes(remotes_list)
+            datasets = self.get_datasets(remotes_list)
 
         else:
             pass
 
 
-    def get_remotes(self, remotes_list, threads=20):
+    def get_datasets(self, remotes_list, threads=30):
         """
-        The function to get many datasets from many remotes.
+        The function to get datasets from many remotes.
 
         Parameters
         ----------
@@ -78,7 +79,7 @@ class Tethys(object):
             connection_config : dict or str
                 A dict of strings of service_name, s3, endpoint_url, aws_access_key_id, and aws_secret_access_key. Or it could be a string of the public_url endpoint.
         threads : int
-            The number of threads to use. I.E. the number of simultaneous remote reads.
+            The number of threads to use. I.e. the number of simultaneous remote reads.
 
         Returns
         -------
@@ -90,7 +91,7 @@ class Tethys(object):
         return self.datasets
 
 
-    def get_datasets(self, remote):
+    def get_remote_datasets(self, remote):
         """
         Get datasets from an individual remote. Saves result into the object.
 
@@ -126,7 +127,7 @@ class Tethys(object):
             print('No datasets.json.zst file in S3 bucket')
 
 
-    def get_stations(self, dataset_id):
+    def get_stations(self, dataset_id, results_object_keys=False):
         """
         Method to return the stations associated with a dataset.
 
@@ -134,6 +135,8 @@ class Tethys(object):
         ----------
         dataset_id : str
             The dataset_id of the dataset.
+        results_object_keys : bool
+            Shoud the results object keys be returned? The results object keys list the available results in Tethys.
 
         Returns
         -------
@@ -149,10 +152,13 @@ class Tethys(object):
             stn_list = read_json_zstd(stn_obj)
             stn_list = [s for s in stn_list if isinstance(s, dict)]
 
-            self._stations.update({dataset_id: {s['station_id']: s for s in stn_list}})
+            self._stations.update({dataset_id: {s['station_id']: s for s in copy.deepcopy(stn_list)}})
 
             # TODO: Run spatial query here!
 
+            if not results_object_keys:
+                s = [s.pop('results_object_key') for s in stn_list]
+
             return stn_list
 
         except:
@@ -326,4 +332,3 @@ class Tethys(object):
 
 ######################################
 ### Testing
-
