@@ -23,12 +23,13 @@ remote = remotes_list[0]
 # remote['connection_config'] = 'https://b2.tethys-ts.xyz'
 #
 dataset_id = '4edc94c19bf074027bc7c099'
-# dataset_id = '10456b32c1eb6f20339d16b4'
+# dataset_id = 'dddb02cd5cb7ae191311ab19'
+station_id = 'fedeb59e6c7f47597a7d47c7'
 # station_id = 'f79f0ddc99428b73c2293513'
 station_id = '6b75a7fb1453ef94148bda19'
 # station_ids = [station_id, 'f74d29232b5d5c094effe9e2']
-# dataset_id='74c5bcd07846abae0e28ddd2'
-# station_id='fabdf416a8644a713e221fd6'
+# dataset_id='73ab8b02fc65686636eb6d0b'
+# station_id='489de57745076fb4ff2bd91b'
 # dataset_id='ad3156ce8245f725a5a0cda8'
 # station_id='6b5dc8c9ec394b2c4167f6b8'
 #
@@ -39,7 +40,7 @@ self = Tethys(remotes_list)
 stn_list1 = self.get_stations(dataset_id)
 # run_dates = self.get_run_dates(dataset_id, station_id)
 data1 = self.get_results(dataset_id, station_id, remove_height=True, output='Dataset')
-# data1 = self.get_results(dataset_id, station_id, modified_date=True, quality_code=True, output='DataArray')
+# data1 = self.get_results(dataset_id, station_id, modified_date=True, quality_code=True, remove_height=True, output='DataArray')
 # data1 = self.get_results(dataset_id, station_id, modified_date=True, quality_code=True, remove_height=True, output='DataArray')
 # data1 = self.get_results(dataset_id, station_id, modified_date=True, quality_code=True, output='Dict')
 # data1 = self.get_results(dataset_id, station_id, output='Dict')
@@ -50,9 +51,9 @@ data1 = self.get_results(dataset_id, station_id, remove_height=True, output='Dat
 # dataset_id = 'f4cfb5a362707785dd39ff85'
 # station_id = 'ff4213c61878e098e07df513'
 
+stn = [s for s in stn_list1 if s['ref'] == '1071103']
 
-
-
+dsid = [ds for ds in self.datasets if
 
 
 
